@@ -16,6 +16,7 @@ import (
 	"github.com/hahwul/dalfox/v2/pkg/optimization"
 	"github.com/hahwul/dalfox/v2/pkg/printing"
 	"github.com/hahwul/dalfox/v2/pkg/verification"
+	vlogger "github.com/hahwul/volt/logger"
 )
 
 func setP(p, dp url.Values, name string, options model.Options) (url.Values, url.Values) {
@@ -34,6 +35,8 @@ func setP(p, dp url.Values, name string, options model.Options) (url.Values, url
 func ParameterAnalysis(target string, options model.Options, rl *rateLimiter) map[string][]string {
 	//miningCheckerSize := 0
 	miningCheckerLine := 0
+	vLog := vlogger.GetLogger(options.Debug)
+	pLog := vLog.WithField("data1", "PA")
 	u, err := url.Parse(target)
 	params := make(map[string][]string)
 	if err != nil {
@@ -136,57 +139,61 @@ func ParameterAnalysis(target string, options model.Options, rl *rateLimiter) ma
 				switch tres.Header.Get("Content-Encoding") {
 				case "gzip":
 					reader, err = gzip.NewReader(tres.Body)
+					if err != nil {
+						reader = tres.Body
+					}
 					defer reader.Close()
 				default:
 					reader = tres.Body
 				}
-
-				bodyString, _ := ioutil.ReadAll(reader)
-				body := ioutil.NopCloser(strings.NewReader(string(bodyString)))
-				defer body.Close()
-				doc, err := goquery.NewDocumentFromReader(body)
+				bodyString, err := ioutil.ReadAll(reader)
 				if err == nil {
-					count := 0
-					doc.Find("input").Each(func(i int, s *goquery.Selection) {
-						name, _ := s.Attr("name")
-						p, dp = setP(p, dp, name, options)
-						count = count + 1
-					})
-					doc.Find("textarea").Each(func(i int, s *goquery.Selection) {
-						name, _ := s.Attr("name")
-						p, dp = setP(p, dp, name, options)
-						count = count + 1
-					})
-					doc.Find("select").Each(func(i int, s *goquery.Selection) {
-						name, _ := s.Attr("name")
-						p, dp = setP(p, dp, name, options)
-						count = count + 1
-					})
-					doc.Find("form").Each(func(i int, s *goquery.Selection) {
-						action, _ := s.Attr("action")
-						if strings.HasPrefix(action, "/") || strings.HasPrefix(action, "?") { // assuming this is a relative URL
-							url, _ := url.Parse(action)
-							query := url.Query()
-							for aParam := range query {
-								p, dp = setP(p, dp, aParam, options)
-								count = count + 1
-							}
+					body := ioutil.NopCloser(strings.NewReader(string(bodyString)))
+					defer body.Close()
+					doc, err := goquery.NewDocumentFromReader(body)
+					if err == nil {
+						count := 0
+						doc.Find("input").Each(func(i int, s *goquery.Selection) {
+							name, _ := s.Attr("name")
+							p, dp = setP(p, dp, name, options)
+							count = count + 1
+						})
+						doc.Find("textarea").Each(func(i int, s *goquery.Selection) {
+							name, _ := s.Attr("name")
+							p, dp = setP(p, dp, name, options)
+							count = count + 1
+						})
+						doc.Find("select").Each(func(i int, s *goquery.Selection) {
+							name, _ := s.Attr("name")
+							p, dp = setP(p, dp, name, options)
+							count = count + 1
+						})
+						doc.Find("form").Each(func(i int, s *goquery.Selection) {
+							action, _ := s.Attr("action")
+							if strings.HasPrefix(action, "/") || strings.HasPrefix(action, "?") { // assuming this is a relative URL
+								url, _ := url.Parse(action)
+								query := url.Query()
+								for aParam := range query {
+									p, dp = setP(p, dp, aParam, options)
+									count = count + 1
+								}
 
-						}
-					})
-					doc.Find("a").Each(func(i int, s *goquery.Selection) {
-						href, _ := s.Attr("href")
-						if strings.HasPrefix(href, "/") || strings.HasPrefix(href, "?") { // assuming this is a relative URL
-							url, _ := url.Parse(href)
-							query := url.Query()
-							for aParam := range query {
-								p, dp = setP(p, dp, aParam, options)
-								count = count + 1
 							}
+						})
+						doc.Find("a").Each(func(i int, s *goquery.Selection) {
+							href, _ := s.Attr("href")
+							if strings.HasPrefix(href, "/") || strings.HasPrefix(href, "?") { // assuming this is a relative URL
+								url, _ := url.Parse(href)
+								query := url.Query()
+								for aParam := range query {
+									p, dp = setP(p, dp, aParam, options)
+									count = count + 1
+								}
 
-						}
-					})
-					printing.DalLog("INFO", "Found "+strconv.Itoa(count)+" testing point in DOM base parameter mining", options)
+							}
+						})
+						printing.DalLog("INFO", "Found "+strconv.Itoa(count)+" testing point in DOM base parameter mining", options)
+					}
 				}
 			}
 		}
@@ -228,7 +235,10 @@ func ParameterAnalysis(target string, options model.Options, rl *rateLimiter) ma
 					}
 					_, lineSum := verification.VerifyReflectionWithLine(resbody, "DalFox")
 					if miningCheckerLine == lineSum {
-						vrs = false
+						pLog.Debug("Hit linesum")
+						pLog.Debug(lineSum)
+						//vrs = false
+						//(#354) It can cause a lot of misconceptions. removed it.
 					}
 					if vrs {
 						code = CodeView(resbody, "DalFox")
@@ -316,6 +326,7 @@ func ParameterAnalysis(target string, options model.Options, rl *rateLimiter) ma
 					_, lineSum := verification.VerifyReflectionWithLine(resbody, "DalFox")
 					//fmt.Printf("%s => %d : %d\n", k, miningCheckerLine, lineSum)
 					if miningCheckerLine == lineSum {
+
 						vrs = false
 					}
 					if vrs {
@@ -392,6 +403,7 @@ func ParameterAnalysis(target string, options model.Options, rl *rateLimiter) ma
 	return params
 }
 
+// GetPType is Get Parameter Type
 func GetPType(av string) string {
 	if strings.Contains(av, "PTYPE: URL") {
 		return "-URL"
